# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: apexnova/market/market.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'apexnova/market/market.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x61pexnova/market/market.proto\x12\x08\x61pexnova\x1a\x1fgoogle/protobuf/timestamp.proto\"[\n\tQuoteInfo\x12\x0e\n\x06volume\x18\x01 \x01(\x05\x12\x0f\n\x07\x64\x61y_low\x18\x02 \x01(\x02\x12\x10\n\x08\x64\x61y_high\x18\x03 \x01(\x02\x12\x0c\n\x04open\x18\x04 \x01(\x02\x12\r\n\x05\x63lose\x18\x05 \x01(\x02\"\x81\x02\n\x05Stock\x12\x14\n\x0c\x63ompany_name\x18\x01 \x01(\t\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12)\n\x08\x65xchange\x18\x03 \x01(\x0e\x32\x17.apexnova.StockExchange\x12\"\n\x07\x63ountry\x18\x04 \x01(\x0e\x32\x11.apexnova.Country\x12$\n\x08\x63urrency\x18\x05 \x01(\x0e\x32\x12.apexnova.Currency\x12 \n\x06sector\x18\x06 \x01(\x0e\x32\x10.apexnova.Sector\x12\x11\n\timage_url\x18\x07 \x01(\t\x12\x0b\n\x03\x63ik\x18\x08 \x01(\t\x12\x0c\n\x04isin\x18\t \x01(\t\x12\r\n\x05\x63usip\x18\n \x01(\t\"\x99\r\n\x15\x42\x61lanceSheetStatement\x12)\n\x0b\x66iscal_year\x18\x01 \x01(\x0e\x32\x14.apexnova.FiscalYear\x12)\n\x06period\x18\x02 \x01(\x0e\x32\x19.apexnova.ReportingPeriod\x12/\n\x0b\x66iling_date\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10\x63\x61sh_equivalents\x18\x04 \x01(\x03\x12\x1e\n\x16short_term_investments\x18\x05 \x01(\x03\x12#\n\x1b\x63\x61sh_short_term_investments\x18\x06 \x01(\x03\x12\x17\n\x0fnet_receivables\x18\x07 \x01(\x03\x12\x1c\n\x14\x61\x63\x63ounts_receivables\x18\x08 \x01(\x03\x12\x19\n\x11other_receivables\x18\t \x01(\x03\x12\x11\n\tinventory\x18\n \x01(\x03\x12\x10\n\x08prepaids\x18\x0b \x01(\x03\x12\x1c\n\x14other_current_assets\x18\x0c \x01(\x03\x12\x1c\n\x14total_current_assets\x18\r \x01(\x03\x12$\n\x1cproperty_plant_equipment_net\x18\x0e \x01(\x03\x12\x10\n\x08goodwill\x18\x0f \x01(\x03\x12\x19\n\x11intangible_assets\x18\x10 \x01(\x03\x12\"\n\x1agoodwill_intangible_assets\x18\x11 \x01(\x03\x12\x1d\n\x15long_term_investments\x18\x12 \x01(\x03\x12\x12\n\ntax_assets\x18\x13 \x01(\x03\x12 \n\x18other_non_current_assets\x18\x14 \x01(\x03\x12 \n\x18total_non_current_assets\x18\x15 \x01(\x03\x12\x14\n\x0cother_assets\x18\x16 \x01(\x03\x12\x14\n\x0ctotal_assets\x18\x17 \x01(\x03\x12\x16\n\x0etotal_payables\x18\x18 \x01(\x03\x12\x18\n\x10\x61\x63\x63ount_payables\x18\x19 \x01(\x03\x12\x16\n\x0eother_payables\x18\x1a \x01(\x03\x12\x18\n\x10\x61\x63\x63rued_expenses\x18\x1b \x01(\x03\x12\x17\n\x0fshort_term_debt\x18\x1c \x01(\x03\x12)\n!capital_lease_obligations_current\x18\x1d \x01(\x03\x12\x14\n\x0ctax_payables\x18\x1e \x01(\x03\x12\x18\n\x10\x64\x65\x66\x65rred_revenue\x18\x1f \x01(\x03\x12!\n\x19other_current_liabilities\x18  \x01(\x03\x12!\n\x19total_current_liabilities\x18! \x01(\x03\x12\x16\n\x0elong_term_debt\x18\" \x01(\x03\x12$\n\x1c\x64\x65\x66\x65rred_revenue_non_current\x18# \x01(\x03\x12,\n$deferred_tax_liabilities_non_current\x18$ \x01(\x03\x12%\n\x1dother_non_current_liabilities\x18% \x01(\x03\x12%\n\x1dtotal_non_current_liabilities\x18& \x01(\x03\x12\x19\n\x11other_liabilities\x18\' \x01(\x03\x12!\n\x19\x63\x61pital_lease_obligations\x18( \x01(\x03\x12\x19\n\x11total_liabilities\x18) \x01(\x03\x12\x16\n\x0etreasury_stock\x18* \x01(\x03\x12\x17\n\x0fpreferred_stock\x18+ \x01(\x03\x12\x14\n\x0c\x63ommon_stock\x18, \x01(\x03\x12\x19\n\x11retained_earnings\x18- \x01(\x03\x12\x1f\n\x17\x61\x64\x64itional_paid_capital\x18. \x01(\x03\x12\x33\n+accumulated_other_comprehensive_income_loss\x18/ \x01(\x03\x12\'\n\x1fother_total_stockholders_equity\x18\x30 \x01(\x03\x12!\n\x19total_stockholders_equity\x18\x31 \x01(\x03\x12\x14\n\x0ctotal_equity\x18\x32 \x01(\x03\x12\x19\n\x11minority_interest\x18\x33 \x01(\x03\x12&\n\x1etotal_liabilities_total_equity\x18\x34 \x01(\x03\x12\x19\n\x11total_investments\x18\x35 \x01(\x03\x12\x12\n\ntotal_debt\x18\x36 \x01(\x03\x12\x10\n\x08net_debt\x18\x37 \x01(\x03\"\xe4\n\n\x11\x43\x61shflowStatement\x12)\n\x0b\x66iscal_year\x18\x01 \x01(\x0e\x32\x14.apexnova.FiscalYear\x12)\n\x06period\x18\x02 \x01(\x0e\x32\x19.apexnova.ReportingPeriod\x12/\n\x0b\x66iling_date\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nnet_income\x18\x04 \x01(\x03\x12!\n\x19\x64\x65preciation_amortization\x18\x05 \x01(\x03\x12\x1b\n\x13\x64\x65\x66\x65rred_income_tax\x18\x06 \x01(\x03\x12 \n\x18stock_based_compensation\x18\x07 \x01(\x03\x12\x1e\n\x16\x63hange_working_capital\x18\x08 \x01(\x03\x12\x1c\n\x14\x61\x63\x63ounts_receivables\x18\t \x01(\x03\x12\x11\n\tinventory\x18\n \x01(\x03\x12\x19\n\x11\x61\x63\x63ounts_payables\x18\x0b \x01(\x03\x12\x1d\n\x15other_working_capital\x18\x0c \x01(\x03\x12\x1c\n\x14other_non_cash_items\x18\r \x01(\x03\x12%\n\x1dnet_cash_operating_activities\x18\x0e \x01(\x03\x12,\n$investments_property_plant_equipment\x18\x0f \x01(\x03\x12\x18\n\x10\x61\x63quisitions_net\x18\x10 \x01(\x03\x12\x1d\n\x15purchases_investments\x18\x11 \x01(\x03\x12$\n\x1csales_maturities_investments\x18\x12 \x01(\x03\x12\"\n\x1aother_investing_activities\x18\x13 \x01(\x03\x12%\n\x1dnet_cash_investing_activities\x18\x14 \x01(\x03\x12\x19\n\x11net_debt_issuance\x18\x15 \x01(\x03\x12#\n\x1blong_term_net_debt_issuance\x18\x16 \x01(\x03\x12$\n\x1cshort_term_net_debt_issuance\x18\x17 \x01(\x03\x12\x1a\n\x12net_stock_issuance\x18\x18 \x01(\x03\x12!\n\x19net_common_stock_issuance\x18\x19 \x01(\x03\x12\x1d\n\x15\x63ommon_stock_issuance\x18\x1a \x01(\x03\x12 \n\x18\x63ommon_stock_repurchased\x18\x1b \x01(\x03\x12$\n\x1cnet_preferred_stock_issuance\x18\x1c \x01(\x03\x12\x1a\n\x12net_dividends_paid\x18\x1d \x01(\x03\x12\x1d\n\x15\x63ommon_dividends_paid\x18\x1e \x01(\x03\x12 \n\x18preferred_dividends_paid\x18\x1f \x01(\x03\x12\"\n\x1aother_financing_activities\x18  \x01(\x03\x12%\n\x1dnet_cash_financing_activities\x18! \x01(\x03\x12!\n\x19\x65\x66\x66\x65\x63t_forex_changes_cash\x18\" \x01(\x03\x12\x17\n\x0fnet_change_cash\x18# \x01(\x03\x12\x17\n\x0f\x63\x61sh_end_period\x18$ \x01(\x03\x12\x1d\n\x15\x63\x61sh_beginning_period\x18% \x01(\x03\x12\x1b\n\x13operating_cash_flow\x18& \x01(\x03\x12\x1b\n\x13\x63\x61pital_expenditure\x18\' \x01(\x03\x12\x16\n\x0e\x66ree_cash_flow\x18( \x01(\x03\x12\x19\n\x11income_taxes_paid\x18) \x01(\x03\x12\x15\n\rinterest_paid\x18* \x01(\x03\"\xba\x08\n\x0fIncomeStatement\x12)\n\x0b\x66iscal_year\x18\x01 \x01(\x0e\x32\x14.apexnova.FiscalYear\x12)\n\x06period\x18\x02 \x01(\x0e\x32\x19.apexnova.ReportingPeriod\x12/\n\x0b\x66iling_date\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07revenue\x18\x04 \x01(\x03\x12\x14\n\x0c\x63ost_revenue\x18\x05 \x01(\x03\x12\x14\n\x0cgross_profit\x18\x06 \x01(\x03\x12%\n\x1dresearch_development_expenses\x18\x07 \x01(\x03\x12\'\n\x1fgeneral_administrative_expenses\x18\x08 \x01(\x03\x12\"\n\x1aselling_marketing_expenses\x18\t \x01(\x03\x12/\n\'selling_general_administrative_expenses\x18\n \x01(\x03\x12\x16\n\x0eother_expenses\x18\x0b \x01(\x03\x12\x1a\n\x12operating_expenses\x18\x0c \x01(\x03\x12\x15\n\rcost_expenses\x18\r \x01(\x03\x12\x1b\n\x13net_interest_income\x18\x0e \x01(\x03\x12\x17\n\x0finterest_income\x18\x0f \x01(\x03\x12\x18\n\x10interest_expense\x18\x10 \x01(\x03\x12!\n\x19\x64\x65preciation_amortization\x18\x11 \x01(\x03\x12\x0e\n\x06\x65\x62itda\x18\x12 \x01(\x03\x12\x0c\n\x04\x65\x62it\x18\x13 \x01(\x03\x12/\n\'non_operating_income_excluding_interest\x18\x14 \x01(\x03\x12\x18\n\x10operating_income\x18\x15 \x01(\x03\x12\'\n\x1ftotal_other_income_expenses_net\x18\x16 \x01(\x03\x12\x19\n\x11income_before_tax\x18\x17 \x01(\x03\x12\x1a\n\x12income_tax_expense\x18\x18 \x01(\x03\x12(\n net_income_continuing_operations\x18\x19 \x01(\x03\x12*\n\"net_income_discontinued_operations\x18\x1a \x01(\x03\x12$\n\x1cother_adjustments_net_income\x18\x1b \x01(\x03\x12\x12\n\nnet_income\x18\x1c \x01(\x03\x12\x1d\n\x15net_income_deductions\x18\x1d \x01(\x03\x12\x1e\n\x16\x62ottom_line_net_income\x18\x1e \x01(\x03\x12\x0b\n\x03\x65ps\x18\x1f \x01(\x02\x12\x13\n\x0b\x65ps_diluted\x18  \x01(\x02\x12 \n\x18weighted_average_shs_out\x18! \x01(\x03\x12$\n\x1cweighted_average_shs_out_dil\x18\" \x01(\x03*\xb0\x06\n\x07\x43ountry\x12\x17\n\x13\x43OUNTRY_UNSPECIFIED\x10\x00\x12\x0f\n\x0b\x43OUNTRY_USA\x10\x01\x12\x12\n\x0e\x43OUNTRY_CANADA\x10\x02\x12\x0e\n\nCOUNTRY_UK\x10\x03\x12\x13\n\x0f\x43OUNTRY_GERMANY\x10\x04\x12\x12\n\x0e\x43OUNTRY_FRANCE\x10\x05\x12\x11\n\rCOUNTRY_ITALY\x10\x06\x12\x11\n\rCOUNTRY_SPAIN\x10\x07\x12\x17\n\x13\x43OUNTRY_NETHERLANDS\x10\x08\x12\x17\n\x13\x43OUNTRY_SWITZERLAND\x10\t\x12\x12\n\x0e\x43OUNTRY_SWEDEN\x10\n\x12\x12\n\x0e\x43OUNTRY_NORWAY\x10\x0b\x12\x13\n\x0f\x43OUNTRY_DENMARK\x10\x0c\x12\x11\n\rCOUNTRY_JAPAN\x10\r\x12\x11\n\rCOUNTRY_CHINA\x10\x0e\x12\x15\n\x11\x43OUNTRY_HONG_KONG\x10\x0f\x12\x17\n\x13\x43OUNTRY_SOUTH_KOREA\x10\x10\x12\x15\n\x11\x43OUNTRY_SINGAPORE\x10\x11\x12\x11\n\rCOUNTRY_INDIA\x10\x12\x12\x15\n\x11\x43OUNTRY_AUSTRALIA\x10\x13\x12\x17\n\x13\x43OUNTRY_NEW_ZEALAND\x10\x14\x12\x12\n\x0e\x43OUNTRY_BRAZIL\x10\x15\x12\x12\n\x0e\x43OUNTRY_MEXICO\x10\x16\x12\x15\n\x11\x43OUNTRY_ARGENTINA\x10\x17\x12\x11\n\rCOUNTRY_CHILE\x10\x18\x12\x12\n\x0e\x43OUNTRY_RUSSIA\x10\x19\x12\x18\n\x14\x43OUNTRY_SOUTH_AFRICA\x10\x1a\x12\x12\n\x0e\x43OUNTRY_ISRAEL\x10\x1b\x12\x12\n\x0e\x43OUNTRY_TURKEY\x10\x1c\x12\x18\n\x14\x43OUNTRY_SAUDI_ARABIA\x10\x1d\x12\x0f\n\x0b\x43OUNTRY_UAE\x10\x1e\x12\x12\n\x0e\x43OUNTRY_TAIWAN\x10\x1f\x12\x14\n\x10\x43OUNTRY_THAILAND\x10 \x12\x14\n\x10\x43OUNTRY_MALAYSIA\x10!\x12\x15\n\x11\x43OUNTRY_INDONESIA\x10\"\x12\x17\n\x13\x43OUNTRY_PHILIPPINES\x10#\x12\x13\n\x0f\x43OUNTRY_VIETNAM\x10$\x12\x11\n\rCOUNTRY_OTHER\x10\x63*\x88\x06\n\x08\x43urrency\x12\x18\n\x14\x43URRENCY_UNSPECIFIED\x10\x00\x12\x10\n\x0c\x43URRENCY_USD\x10\x01\x12\x10\n\x0c\x43URRENCY_EUR\x10\x02\x12\x10\n\x0c\x43URRENCY_GBP\x10\x03\x12\x10\n\x0c\x43URRENCY_CAD\x10\x04\x12\x10\n\x0c\x43URRENCY_JPY\x10\x05\x12\x10\n\x0c\x43URRENCY_CNY\x10\x06\x12\x10\n\x0c\x43URRENCY_HKD\x10\x07\x12\x10\n\x0c\x43URRENCY_AUD\x10\x08\x12\x10\n\x0c\x43URRENCY_CHF\x10\t\x12\x10\n\x0c\x43URRENCY_SEK\x10\n\x12\x10\n\x0c\x43URRENCY_NOK\x10\x0b\x12\x10\n\x0c\x43URRENCY_DKK\x10\x0c\x12\x10\n\x0c\x43URRENCY_NZD\x10\r\x12\x10\n\x0c\x43URRENCY_SGD\x10\x0e\x12\x10\n\x0c\x43URRENCY_KRW\x10\x0f\x12\x10\n\x0c\x43URRENCY_INR\x10\x10\x12\x10\n\x0c\x43URRENCY_BRL\x10\x11\x12\x10\n\x0c\x43URRENCY_MXN\x10\x12\x12\x10\n\x0c\x43URRENCY_RUB\x10\x13\x12\x10\n\x0c\x43URRENCY_ZAR\x10\x14\x12\x10\n\x0c\x43URRENCY_TRY\x10\x15\x12\x10\n\x0c\x43URRENCY_ILS\x10\x16\x12\x10\n\x0c\x43URRENCY_SAR\x10\x17\x12\x10\n\x0c\x43URRENCY_AED\x10\x18\x12\x10\n\x0c\x43URRENCY_TWD\x10\x19\x12\x10\n\x0c\x43URRENCY_THB\x10\x1a\x12\x10\n\x0c\x43URRENCY_MYR\x10\x1b\x12\x10\n\x0c\x43URRENCY_IDR\x10\x1c\x12\x10\n\x0c\x43URRENCY_PHP\x10\x1d\x12\x10\n\x0c\x43URRENCY_VND\x10\x1e\x12\x10\n\x0c\x43URRENCY_PLN\x10\x1f\x12\x10\n\x0c\x43URRENCY_CZK\x10 \x12\x10\n\x0c\x43URRENCY_HUF\x10!\x12\x10\n\x0c\x43URRENCY_RON\x10\"\x12\x10\n\x0c\x43URRENCY_HRK\x10#\x12\x10\n\x0c\x43URRENCY_BGN\x10$\x12\x10\n\x0c\x43URRENCY_ARS\x10%\x12\x10\n\x0c\x43URRENCY_CLP\x10&\x12\x10\n\x0c\x43URRENCY_COP\x10\'\x12\x10\n\x0c\x43URRENCY_PEN\x10(\x12\x12\n\x0e\x43URRENCY_OTHER\x10\x63*\xc2\x02\n\x06Sector\x12\x16\n\x12SECTOR_UNSPECIFIED\x10\x00\x12\x1a\n\x16SECTOR_BASIC_MATERIALS\x10\x01\x12!\n\x1dSECTOR_COMMUNICATION_SERVICES\x10\x02\x12\x1c\n\x18SECTOR_CONSUMER_CYCLICAL\x10\x03\x12\x1d\n\x19SECTOR_CONSUMER_DEFENSIVE\x10\x04\x12\x11\n\rSECTOR_ENERGY\x10\x05\x12\x1d\n\x19SECTOR_FINANCIAL_SERVICES\x10\x06\x12\x15\n\x11SECTOR_HEALTHCARE\x10\x07\x12\x16\n\x12SECTOR_INDUSTRIALS\x10\x08\x12\x16\n\x12SECTOR_REAL_ESTATE\x10\t\x12\x15\n\x11SECTOR_TECHNOLOGY\x10\n\x12\x14\n\x10SECTOR_UTILITIES\x10\x0b*\xb4\x01\n\x0fReportingPeriod\x12 \n\x1cREPORTING_PERIOD_UNSPECIFIED\x10\x00\x12\x1b\n\x17REPORTING_PERIOD_ANNUAL\x10\x01\x12\x17\n\x13REPORTING_PERIOD_Q1\x10\x02\x12\x17\n\x13REPORTING_PERIOD_Q2\x10\x03\x12\x17\n\x13REPORTING_PERIOD_Q3\x10\x04\x12\x17\n\x13REPORTING_PERIOD_Q4\x10\x05*}\n\rStockExchange\x12\x1e\n\x1aSTOCK_EXCHANGE_UNSPECIFIED\x10\x00\x12\x17\n\x13STOCK_EXCHANGE_NYSE\x10\x01\x12\x19\n\x15STOCK_EXCHANGE_NASDAQ\x10\x02\x12\x18\n\x14STOCK_EXCHANGE_OTHER\x10\x03*\xa6\x02\n\nFiscalYear\x12\x1b\n\x17\x46ISCAL_YEAR_UNSPECIFIED\x10\x00\x12\x15\n\x10\x46ISCAL_YEAR_2015\x10\xdf\x0f\x12\x15\n\x10\x46ISCAL_YEAR_2016\x10\xe0\x0f\x12\x15\n\x10\x46ISCAL_YEAR_2017\x10\xe1\x0f\x12\x15\n\x10\x46ISCAL_YEAR_2018\x10\xe2\x0f\x12\x15\n\x10\x46ISCAL_YEAR_2019\x10\xe3\x0f\x12\x15\n\x10\x46ISCAL_YEAR_2020\x10\xe4\x0f\x12\x15\n\x10\x46ISCAL_YEAR_2021\x10\xe5\x0f\x12\x15\n\x10\x46ISCAL_YEAR_2022\x10\xe6\x0f\x12\x15\n\x10\x46ISCAL_YEAR_2023\x10\xe7\x0f\x12\x15\n\x10\x46ISCAL_YEAR_2024\x10\xe8\x0f\x12\x15\n\x10\x46ISCAL_YEAR_2025\x10\xe9\x0f\x42#\n\x13\x63om.apexnova.marketB\nStockProtoP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'apexnova.market.market_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.apexnova.marketB\nStockProtoP\001'
  _globals['_COUNTRY']._serialized_start=4589
  _globals['_COUNTRY']._serialized_end=5405
  _globals['_CURRENCY']._serialized_start=5408
  _globals['_CURRENCY']._serialized_end=6184
  _globals['_SECTOR']._serialized_start=6187
  _globals['_SECTOR']._serialized_end=6509
  _globals['_REPORTINGPERIOD']._serialized_start=6512
  _globals['_REPORTINGPERIOD']._serialized_end=6692
  _globals['_STOCKEXCHANGE']._serialized_start=6694
  _globals['_STOCKEXCHANGE']._serialized_end=6819
  _globals['_FISCALYEAR']._serialized_start=6822
  _globals['_FISCALYEAR']._serialized_end=7116
  _globals['_QUOTEINFO']._serialized_start=75
  _globals['_QUOTEINFO']._serialized_end=166
  _globals['_STOCK']._serialized_start=169
  _globals['_STOCK']._serialized_end=426
  _globals['_BALANCESHEETSTATEMENT']._serialized_start=429
  _globals['_BALANCESHEETSTATEMENT']._serialized_end=2118
  _globals['_CASHFLOWSTATEMENT']._serialized_start=2121
  _globals['_CASHFLOWSTATEMENT']._serialized_end=3501
  _globals['_INCOMESTATEMENT']._serialized_start=3504
  _globals['_INCOMESTATEMENT']._serialized_end=4586
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: apexnova/market/market_service.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'apexnova/market/market_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from apexnova.market import market_pb2 as apexnova_dot_market_dot_market__pb2
from apexnova.stub import authorization_context_pb2 as apexnova_dot_stub_dot_authorization__context__pb2
from apexnova.stub import response_pb2 as apexnova_dot_stub_dot_response__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$apexnova/market/market_service.proto\x12\x08\x61pexnova\x1a\x1c\x61pexnova/market/market.proto\x1a)apexnova/stub/authorization_context.proto\x1a\x1c\x61pexnova/stub/response.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"a\n\x10ReadStockRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12=\n\x15\x61uthorization_context\x18\x02 \x01(\x0b\x32\x1e.apexnova.AuthorizationContext\"j\n\x11ReadStockResponse\x12\x1e\n\x05stock\x18\x01 \x01(\x0b\x32\x0f.apexnova.Stock\x12\x35\n\x11standard_response\x18\x02 \x01(\x0b\x32\x1a.apexnova.StandardResponse\"\x91\x01\n\x10ReadQuoteRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12.\n\nquote_date\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12=\n\x15\x61uthorization_context\x18\x03 \x01(\x0b\x32\x1e.apexnova.AuthorizationContext\"n\n\x11ReadQuoteResponse\x12\"\n\x05quote\x18\x01 \x01(\x0b\x32\x13.apexnova.QuoteInfo\x12\x35\n\x11standard_response\x18\x02 \x01(\x0b\x32\x1a.apexnova.StandardResponse\"\xdd\x01\n\x17StreamStatementsRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12)\n\x0b\x66iscal_year\x18\x02 \x01(\x0e\x32\x14.apexnova.FiscalYear\x12)\n\x06period\x18\x03 \x01(\x0e\x32\x19.apexnova.ReportingPeriod\x12\x0e\n\x06\x63ursor\x18\x04 \x01(\t\x12\r\n\x05limit\x18\x05 \x01(\x05\x12=\n\x15\x61uthorization_context\x18\x06 \x01(\x0b\x32\x1e.apexnova.AuthorizationContext\"\x8a\x01\n\x1d\x42\x61lanceSheetStatementResponse\x12\x32\n\tstatement\x18\x01 \x01(\x0b\x32\x1f.apexnova.BalanceSheetStatement\x12\x35\n\x11standard_response\x18\x02 \x01(\x0b\x32\x1a.apexnova.StandardResponse\"\x82\x01\n\x19\x43\x61shflowStatementResponse\x12.\n\tstatement\x18\x01 \x01(\x0b\x32\x1b.apexnova.CashflowStatement\x12\x35\n\x11standard_response\x18\x02 \x01(\x0b\x32\x1a.apexnova.StandardResponse\"~\n\x17IncomeStatementResponse\x12,\n\tstatement\x18\x01 \x01(\x0b\x32\x19.apexnova.IncomeStatement\x12\x35\n\x11standard_response\x18\x02 \x01(\x0b\x32\x1a.apexnova.StandardResponse\"y\n\x13RevenueGrowthFilter\x12$\n\x06period\x18\x01 \x01(\x0e\x32\x14.apexnova.YearPeriod\x12\x1d\n\x15min_growth_percentage\x18\x02 \x01(\x01\x12\x1d\n\x15max_growth_percentage\x18\x03 \x01(\x01\"\x94\x01\n\x18\x46reeCashFlowGrowthFilter\x12$\n\x06period\x18\x01 \x01(\x0e\x32\x14.apexnova.YearPeriod\x12\x1d\n\x15min_growth_percentage\x18\x02 \x01(\x01\x12\x1d\n\x15max_growth_percentage\x18\x03 \x01(\x01\x12\x14\n\x0csbc_adjusted\x18\x04 \x01(\x08\"A\n\x0fMarketCapFilter\x12\x16\n\x0emin_market_cap\x18\x01 \x01(\x01\x12\x16\n\x0emax_market_cap\x18\x02 \x01(\x01\"9\n\x0bTtmPeFilter\x12\x14\n\x0cmin_pe_ratio\x18\x01 \x01(\x01\x12\x14\n\x0cmax_pe_ratio\x18\x02 \x01(\x01\"z\n\x0cMoversFilter\x12(\n\x06period\x18\x01 \x01(\x0e\x32\x18.apexnova.MovementPeriod\x12\x1f\n\x17min_movement_percentage\x18\x02 \x01(\x01\x12\x1f\n\x17max_movement_percentage\x18\x03 \x01(\x01\"\xb3\x03\n\x14StockScreenerRequest\x12\x35\n\x0erevenue_growth\x18\x01 \x01(\x0b\x32\x1d.apexnova.RevenueGrowthFilter\x12\x36\n\nfcf_growth\x18\x02 \x01(\x0b\x32\".apexnova.FreeCashFlowGrowthFilter\x12-\n\nmarket_cap\x18\x03 \x01(\x0b\x32\x19.apexnova.MarketCapFilter\x12\"\n\x07\x63ountry\x18\x04 \x01(\x0e\x32\x11.apexnova.Country\x12%\n\x06ttm_pe\x18\x05 \x01(\x0b\x32\x15.apexnova.TtmPeFilter\x12)\n\x08\x65xchange\x18\x06 \x01(\x0e\x32\x17.apexnova.StockExchange\x12 \n\x06sector\x18\x07 \x01(\x0e\x32\x10.apexnova.Sector\x12&\n\x06movers\x18\x08 \x01(\x0b\x32\x16.apexnova.MoversFilter\x12=\n\x15\x61uthorization_context\x18\t \x01(\x0b\x32\x1e.apexnova.AuthorizationContext\"n\n\x15StockScreenerResponse\x12\x1e\n\x05stock\x18\x01 \x01(\x0b\x32\x0f.apexnova.Stock\x12\x35\n\x11standard_response\x18\x02 \x01(\x0b\x32\x1a.apexnova.StandardResponse*\x8e\x01\n\nYearPeriod\x12\x1b\n\x17YEAR_PERIOD_UNSPECIFIED\x10\x00\x12\x12\n\x0eYEAR_PERIOD_1Y\x10\x01\x12\x12\n\x0eYEAR_PERIOD_2Y\x10\x02\x12\x12\n\x0eYEAR_PERIOD_3Y\x10\x03\x12\x12\n\x0eYEAR_PERIOD_5Y\x10\x04\x12\x13\n\x0fYEAR_PERIOD_10Y\x10\x05*\xaa\x01\n\x0eMovementPeriod\x12\x1f\n\x1bMOVEMENT_PERIOD_UNSPECIFIED\x10\x00\x12\x16\n\x12MOVEMENT_PERIOD_1D\x10\x01\x12\x16\n\x12MOVEMENT_PERIOD_1W\x10\x02\x12\x16\n\x12MOVEMENT_PERIOD_1M\x10\x03\x12\x16\n\x12MOVEMENT_PERIOD_1Y\x10\x04\x12\x17\n\x13MOVEMENT_PERIOD_YTD\x10\x05\x32\xa4\x04\n\x0cStockService\x12\x44\n\tReadStock\x12\x1a.apexnova.ReadStockRequest\x1a\x1b.apexnova.ReadStockResponse\x12\x44\n\tReadQuote\x12\x1a.apexnova.ReadQuoteRequest\x1a\x1b.apexnova.ReadQuoteResponse\x12l\n\x1cStreamBalanceSheetStatements\x12!.apexnova.StreamStatementsRequest\x1a\'.apexnova.BalanceSheetStatementResponse0\x01\x12\x64\n\x18StreamCashflowStatements\x12!.apexnova.StreamStatementsRequest\x1a#.apexnova.CashflowStatementResponse0\x01\x12`\n\x16StreamIncomeStatements\x12!.apexnova.StreamStatementsRequest\x1a!.apexnova.IncomeStatementResponse0\x01\x12R\n\rStockScreener\x12\x1e.apexnova.StockScreenerRequest\x1a\x1f.apexnova.StockScreenerResponse0\x01\x42*\n\x13\x63om.apexnova.marketB\x11StockServiceProtoP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'apexnova.market.market_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.apexnova.marketB\021StockServiceProtoP\001'
  _globals['_YEARPERIOD']._serialized_start=2354
  _globals['_YEARPERIOD']._serialized_end=2496
  _globals['_MOVEMENTPERIOD']._serialized_start=2499
  _globals['_MOVEMENTPERIOD']._serialized_end=2669
  _globals['_READSTOCKREQUEST']._serialized_start=186
  _globals['_READSTOCKREQUEST']._serialized_end=283
  _globals['_READSTOCKRESPONSE']._serialized_start=285
  _globals['_READSTOCKRESPONSE']._serialized_end=391
  _globals['_READQUOTEREQUEST']._serialized_start=394
  _globals['_READQUOTEREQUEST']._serialized_end=539
  _globals['_READQUOTERESPONSE']._serialized_start=541
  _globals['_READQUOTERESPONSE']._serialized_end=651
  _globals['_STREAMSTATEMENTSREQUEST']._serialized_start=654
  _globals['_STREAMSTATEMENTSREQUEST']._serialized_end=875
  _globals['_BALANCESHEETSTATEMENTRESPONSE']._serialized_start=878
  _globals['_BALANCESHEETSTATEMENTRESPONSE']._serialized_end=1016
  _globals['_CASHFLOWSTATEMENTRESPONSE']._serialized_start=1019
  _globals['_CASHFLOWSTATEMENTRESPONSE']._serialized_end=1149
  _globals['_INCOMESTATEMENTRESPONSE']._serialized_start=1151
  _globals['_INCOMESTATEMENTRESPONSE']._serialized_end=1277
  _globals['_REVENUEGROWTHFILTER']._serialized_start=1279
  _globals['_REVENUEGROWTHFILTER']._serialized_end=1400
  _globals['_FREECASHFLOWGROWTHFILTER']._serialized_start=1403
  _globals['_FREECASHFLOWGROWTHFILTER']._serialized_end=1551
  _globals['_MARKETCAPFILTER']._serialized_start=1553
  _globals['_MARKETCAPFILTER']._serialized_end=1618
  _globals['_TTMPEFILTER']._serialized_start=1620
  _globals['_TTMPEFILTER']._serialized_end=1677
  _globals['_MOVERSFILTER']._serialized_start=1679
  _globals['_MOVERSFILTER']._serialized_end=1801
  _globals['_STOCKSCREENERREQUEST']._serialized_start=1804
  _globals['_STOCKSCREENERREQUEST']._serialized_end=2239
  _globals['_STOCKSCREENERRESPONSE']._serialized_start=2241
  _globals['_STOCKSCREENERRESPONSE']._serialized_end=2351
  _globals['_STOCKSERVICE']._serialized_start=2672
  _globals['_STOCKSERVICE']._serialized_end=3220
# @@protoc_insertion_point(module_scope)



from apexnova.market import market_pb2 as _market_pb2
from apexnova.stub import authorization_context_pb2 as _authorization_context_pb2
from apexnova.stub import response_pb2 as _response_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class YearPeriod(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    YEAR_PERIOD_UNSPECIFIED: _ClassVar[YearPeriod]
    YEAR_PERIOD_1Y: _ClassVar[YearPeriod]
    YEAR_PERIOD_2Y: _ClassVar[YearPeriod]
    YEAR_PERIOD_3Y: _ClassVar[YearPeriod]
    YEAR_PERIOD_5Y: _ClassVar[YearPeriod]
    YEAR_PERIOD_10Y: _ClassVar[YearPeriod]

class MovementPeriod(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    MOVEMENT_PERIOD_UNSPECIFIED: _ClassVar[MovementPeriod]
    MOVEMENT_PERIOD_1D: _ClassVar[MovementPeriod]
    MOVEMENT_PERIOD_1W: _ClassVar[MovementPeriod]
    MOVEMENT_PERIOD_1M: _ClassVar[MovementPeriod]
    MOVEMENT_PERIOD_1Y: _ClassVar[MovementPeriod]
    MOVEMENT_PERIOD_YTD: _ClassVar[MovementPeriod]
YEAR_PERIOD_UNSPECIFIED: YearPeriod
YEAR_PERIOD_1Y: YearPeriod
YEAR_PERIOD_2Y: YearPeriod
YEAR_PERIOD_3Y: YearPeriod
YEAR_PERIOD_5Y: YearPeriod
YEAR_PERIOD_10Y: YearPeriod
MOVEMENT_PERIOD_UNSPECIFIED: MovementPeriod
MOVEMENT_PERIOD_1D: MovementPeriod
MOVEMENT_PERIOD_1W: MovementPeriod
MOVEMENT_PERIOD_1M: MovementPeriod
MOVEMENT_PERIOD_1Y: MovementPeriod
MOVEMENT_PERIOD_YTD: MovementPeriod

class ReadStockRequest(_message.Message):
    __slots__ = ("symbol", "authorization_context")
    SYMBOL_FIELD_NUMBER: _ClassVar[int]
    AUTHORIZATION_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    symbol: str
    authorization_context: _authorization_context_pb2.AuthorizationContext
    def __init__(self, symbol: _Optional[str] = ..., authorization_context: _Optional[_Union[_authorization_context_pb2.AuthorizationContext, _Mapping]] = ...) -> None: ...

class ReadStockResponse(_message.Message):
    __slots__ = ("stock", "standard_response")
    STOCK_FIELD_NUMBER: _ClassVar[int]
    STANDARD_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    stock: _market_pb2.Stock
    standard_response: _response_pb2.StandardResponse
    def __init__(self, stock: _Optional[_Union[_market_pb2.Stock, _Mapping]] = ..., standard_response: _Optional[_Union[_response_pb2.StandardResponse, _Mapping]] = ...) -> None: ...

class ReadQuoteRequest(_message.Message):
    __slots__ = ("symbol", "quote_date", "authorization_context")
    SYMBOL_FIELD_NUMBER: _ClassVar[int]
    QUOTE_DATE_FIELD_NUMBER: _ClassVar[int]
    AUTHORIZATION_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    symbol: str
    quote_date: _timestamp_pb2.Timestamp
    authorization_context: _authorization_context_pb2.AuthorizationContext
    def __init__(self, symbol: _Optional[str] = ..., quote_date: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., authorization_context: _Optional[_Union[_authorization_context_pb2.AuthorizationContext, _Mapping]] = ...) -> None: ...

class ReadQuoteResponse(_message.Message):
    __slots__ = ("quote", "standard_response")
    QUOTE_FIELD_NUMBER: _ClassVar[int]
    STANDARD_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    quote: _market_pb2.QuoteInfo
    standard_response: _response_pb2.StandardResponse
    def __init__(self, quote: _Optional[_Union[_market_pb2.QuoteInfo, _Mapping]] = ..., standard_response: _Optional[_Union[_response_pb2.StandardResponse, _Mapping]] = ...) -> None: ...

class StreamStatementsRequest(_message.Message):
    __slots__ = ("symbol", "fiscal_year", "period", "cursor", "limit", "authorization_context")
    SYMBOL_FIELD_NUMBER: _ClassVar[int]
    FISCAL_YEAR_FIELD_NUMBER: _ClassVar[int]
    PERIOD_FIELD_NUMBER: _ClassVar[int]
    CURSOR_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    AUTHORIZATION_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    symbol: str
    fiscal_year: _market_pb2.FiscalYear
    period: _market_pb2.ReportingPeriod
    cursor: str
    limit: int
    authorization_context: _authorization_context_pb2.AuthorizationContext
    def __init__(self, symbol: _Optional[str] = ..., fiscal_year: _Optional[_Union[_market_pb2.FiscalYear, str]] = ..., period: _Optional[_Union[_market_pb2.ReportingPeriod, str]] = ..., cursor: _Optional[str] = ..., limit: _Optional[int] = ..., authorization_context: _Optional[_Union[_authorization_context_pb2.AuthorizationContext, _Mapping]] = ...) -> None: ...

class BalanceSheetStatementResponse(_message.Message):
    __slots__ = ("statement", "standard_response")
    STATEMENT_FIELD_NUMBER: _ClassVar[int]
    STANDARD_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    statement: _market_pb2.BalanceSheetStatement
    standard_response: _response_pb2.StandardResponse
    def __init__(self, statement: _Optional[_Union[_market_pb2.BalanceSheetStatement, _Mapping]] = ..., standard_response: _Optional[_Union[_response_pb2.StandardResponse, _Mapping]] = ...) -> None: ...

class CashflowStatementResponse(_message.Message):
    __slots__ = ("statement", "standard_response")
    STATEMENT_FIELD_NUMBER: _ClassVar[int]
    STANDARD_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    statement: _market_pb2.CashflowStatement
    standard_response: _response_pb2.StandardResponse
    def __init__(self, statement: _Optional[_Union[_market_pb2.CashflowStatement, _Mapping]] = ..., standard_response: _Optional[_Union[_response_pb2.StandardResponse, _Mapping]] = ...) -> None: ...

class IncomeStatementResponse(_message.Message):
    __slots__ = ("statement", "standard_response")
    STATEMENT_FIELD_NUMBER: _ClassVar[int]
    STANDARD_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    statement: _market_pb2.IncomeStatement
    standard_response: _response_pb2.StandardResponse
    def __init__(self, statement: _Optional[_Union[_market_pb2.IncomeStatement, _Mapping]] = ..., standard_response: _Optional[_Union[_response_pb2.StandardResponse, _Mapping]] = ...) -> None: ...

class RevenueGrowthFilter(_message.Message):
    __slots__ = ("period", "min_growth_percentage", "max_growth_percentage")
    PERIOD_FIELD_NUMBER: _ClassVar[int]
    MIN_GROWTH_PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    MAX_GROWTH_PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    period: YearPeriod
    min_growth_percentage: float
    max_growth_percentage: float
    def __init__(self, period: _Optional[_Union[YearPeriod, str]] = ..., min_growth_percentage: _Optional[float] = ..., max_growth_percentage: _Optional[float] = ...) -> None: ...

class FreeCashFlowGrowthFilter(_message.Message):
    __slots__ = ("period", "min_growth_percentage", "max_growth_percentage", "sbc_adjusted")
    PERIOD_FIELD_NUMBER: _ClassVar[int]
    MIN_GROWTH_PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    MAX_GROWTH_PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    SBC_ADJUSTED_FIELD_NUMBER: _ClassVar[int]
    period: YearPeriod
    min_growth_percentage: float
    max_growth_percentage: float
    sbc_adjusted: bool
    def __init__(self, period: _Optional[_Union[YearPeriod, str]] = ..., min_growth_percentage: _Optional[float] = ..., max_growth_percentage: _Optional[float] = ..., sbc_adjusted: bool = ...) -> None: ...

class MarketCapFilter(_message.Message):
    __slots__ = ("min_market_cap", "max_market_cap")
    MIN_MARKET_CAP_FIELD_NUMBER: _ClassVar[int]
    MAX_MARKET_CAP_FIELD_NUMBER: _ClassVar[int]
    min_market_cap: float
    max_market_cap: float
    def __init__(self, min_market_cap: _Optional[float] = ..., max_market_cap: _Optional[float] = ...) -> None: ...

class TtmPeFilter(_message.Message):
    __slots__ = ("min_pe_ratio", "max_pe_ratio")
    MIN_PE_RATIO_FIELD_NUMBER: _ClassVar[int]
    MAX_PE_RATIO_FIELD_NUMBER: _ClassVar[int]
    min_pe_ratio: float
    max_pe_ratio: float
    def __init__(self, min_pe_ratio: _Optional[float] = ..., max_pe_ratio: _Optional[float] = ...) -> None: ...

class MoversFilter(_message.Message):
    __slots__ = ("period", "min_movement_percentage", "max_movement_percentage")
    PERIOD_FIELD_NUMBER: _ClassVar[int]
    MIN_MOVEMENT_PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    MAX_MOVEMENT_PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    period: MovementPeriod
    min_movement_percentage: float
    max_movement_percentage: float
    def __init__(self, period: _Optional[_Union[MovementPeriod, str]] = ..., min_movement_percentage: _Optional[float] = ..., max_movement_percentage: _Optional[float] = ...) -> None: ...

class StockScreenerRequest(_message.Message):
    __slots__ = ("revenue_growth", "fcf_growth", "market_cap", "country", "ttm_pe", "exchange", "sector", "movers", "authorization_context")
    REVENUE_GROWTH_FIELD_NUMBER: _ClassVar[int]
    FCF_GROWTH_FIELD_NUMBER: _ClassVar[int]
    MARKET_CAP_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    TTM_PE_FIELD_NUMBER: _ClassVar[int]
    EXCHANGE_FIELD_NUMBER: _ClassVar[int]
    SECTOR_FIELD_NUMBER: _ClassVar[int]
    MOVERS_FIELD_NUMBER: _ClassVar[int]
    AUTHORIZATION_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    revenue_growth: RevenueGrowthFilter
    fcf_growth: FreeCashFlowGrowthFilter
    market_cap: MarketCapFilter
    country: _market_pb2.Country
    ttm_pe: TtmPeFilter
    exchange: _market_pb2.StockExchange
    sector: _market_pb2.Sector
    movers: MoversFilter
    authorization_context: _authorization_context_pb2.AuthorizationContext
    def __init__(self, revenue_growth: _Optional[_Union[RevenueGrowthFilter, _Mapping]] = ..., fcf_growth: _Optional[_Union[FreeCashFlowGrowthFilter, _Mapping]] = ..., market_cap: _Optional[_Union[MarketCapFilter, _Mapping]] = ..., country: _Optional[_Union[_market_pb2.Country, str]] = ..., ttm_pe: _Optional[_Union[TtmPeFilter, _Mapping]] = ..., exchange: _Optional[_Union[_market_pb2.StockExchange, str]] = ..., sector: _Optional[_Union[_market_pb2.Sector, str]] = ..., movers: _Optional[_Union[MoversFilter, _Mapping]] = ..., authorization_context: _Optional[_Union[_authorization_context_pb2.AuthorizationContext, _Mapping]] = ...) -> None: ...

class StockScreenerResponse(_message.Message):
    __slots__ = ("stock", "standard_response")
    STOCK_FIELD_NUMBER: _ClassVar[int]
    STANDARD_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    stock: _market_pb2.Stock
    standard_response: _response_pb2.StandardResponse
    def __init__(self, stock: _Optional[_Union[_market_pb2.Stock, _Mapping]] = ..., standard_response: _Optional[_Union[_response_pb2.StandardResponse, _Mapping]] = ...) -> None: ...
